from typing import Annotated
from fastapi import FastAPI, Body, Path
from bij1.erp.models import Member
from trytond.transaction import Transaction
from bij1.erp import pool

app = FastAPI()

user_db = {
    "api": {
        "username": "api",
        "full_name": "API Consumer",
        "email": "api@bij1.org",
        "hashed_password": "7Xtz6TdVpvp5FpkxNFzfFfNtge5IJZsd",
        "disabled": False,
    }
}


@app.get("/")
async def read_root():
    return {"Hello": "World"}


def valid(member: Member) -> bool:
    return False


@app.post("/members/")
async def create_member(
    member: Annotated[
        Member,
        Body(
            openapi_examples={
                "normal": {
                    "summary": "A valid new member to be added",
                    "description": "A new member that does not exist yet",
                    "value": {
                        "name": "Jane Doe",
                        "email": "jane@example.com",
                        "phone": "+31612312312",
                        "address": "Mainstreet 1",
                        "postcode": "1234 AA",
                        "city": "Amsterdam",
                        "status": "Lid",
                        "since": "24-12-2021",
                        "iban": "NL32RABO0137767804",
                        "periode": "per maand",
                        "amount": "10.00",
                        "mandate": "cst_VhCgFjpP94",
                    },
                },
                "ex-lid": {
                    "summary": "A valid former member to be added",
                    "description": "A former member that does not exist yet",
                    "value": {
                        "name": "Jane Doe",
                        "email": "jane@example.com",
                        "phone": "+31612312312",
                        "address": "Mainstreet 1",
                        "postcode": "1234 AA",
                        "city": "Amsterdam",
                        "status": "Ex-lid",
                        "since": "24-12-2021",
                        "until": "15-7-2022",
                        "iban": "NL32RABO0137767804",
                        "periode": "per maand",
                        "amount": "10.00",
                        "mandate": "cst_VhCgFjpP94",
                    },
                },
            }
        ),
    ]
):
    with Transaction().start(pool.database_name, 0):
        if member.exists():
            # return 401
            return member
        if valid(member):
            member.create()
    return member


# @app.put("/members/{member_email}")
async def update_member(
    member_email: Annotated[
        str,
        Path(
            openapi_examples={
                "normal": {
                    "summary": "known email address",
                    "description": "This must be a known email address",
                    "value": "jane@example.com",
                }
            }
        ),
    ],
    member: Annotated[
        Member,
        Body(
            openapi_examples={
                "normal": {
                    "summary": "Update member",
                    "description": "Updated data for known member",
                    "value": {
                        "name": "Jane Doe",
                        "email": "jane@example.com",
                        "phone": "+31612312312",
                        "address": "Mainstreet 1",
                        "postcode": "1234 AA",
                        "city": "Amsterdam",
                        "status": "Lid",
                        "since": "24-12-2021",
                        "iban": "NL32RABO0137767804",
                        "periode": "per maand",
                        "amount": "10.00",
                        "mandate": "cst_VhCgFjpP94",
                    },
                },
            }
        ),
    ],
):
    with Transaction().start(pool.database_name, 0):
        if not member.exists():
            # return 401
            return member

        if valid(member):
            member.update()
    return member
