from decimal import Decimal
from typing import Any
from trytond.transaction import Transaction
from bij1.erp import pool


__all__ = ["config"]

COMPANY_NAME = "BIJ1"
CURRENCY_CODE = "EUR"
CURRENCY_SYMBOL = "€"
SUBSCRIPTION_DESCRIPTION = f"Lidmaatschap {COMPANY_NAME}"


class CONFIG:
    company: Any
    currency: Any
    subscription_description: str = SUBSCRIPTION_DESCRIPTION

    def __init__(self):
        with Transaction().start(pool.database_name, 0):
            self._company()
            self._currency()

    def _party(self):
        Party = pool.get("party.party")
        if not (party := Party.search([("name", "=", COMPANY_NAME)])):
            party = Party()
            party.name = COMPANY_NAME
            party.save()
        else:
            party = party[0]
        return party

    def _company(self):
        Company = pool.get("company.company")
        if not (company := Company.search([("party.name", "=", COMPANY_NAME)])):
            company = Company()
            company.party = self._party()
            company.save()
        else:
            company = company[0]

        self.company = company

    def _currency(self):
        Currency = pool.get("currency.currency")
        if not (currency := Currency.search([("code", "=", "EUR")])):
            currency = Currency()
            currency.rounding = Decimal("0.01")
            currency.digits = 2
        else:
            currency = currency[0]

        currency.code = CURRENCY_CODE
        currency.symbol = CURRENCY_SYMBOL
        currency.save()
        self.currency = currency


config = CONFIG()


def configure():
    pass
